@@ -131,11 +131,10 @@ this to work.
 """
 import functools
 import numbers
-from typing import Any, Callable, FrozenSet, Sequence, Tuple, Optional, overload
+from typing import Any, Callable, FrozenSet, Optional, Sequence, Tuple, overload
 
-from xotl.tools.objects import classproperty
 from xotl.tools.future.types import TEq
-
+from xotl.tools.objects import classproperty
 
 #: The unit for any kind of quantity.
 UNIT = 1
@@ -206,7 +205,8 @@ class Quantity(numbers.Real):
         if isinstance(other, Quantity):
             return downgrade_to_scalar(
                 type(self)(
-                    self.magnitude * other.magnitude, self.signature * other.signature
+                    self.magnitude * other.magnitude,
+                    self.signature * other.signature,
                 )
             )
         else:
@@ -229,7 +229,8 @@ class Quantity(numbers.Real):
         if isinstance(other, Quantity):
             return downgrade_to_scalar(
                 type(self)(
-                    self.magnitude / other.magnitude, self.signature / other.signature
+                    self.magnitude / other.magnitude,
+                    self.signature / other.signature,
                 )
             )
         else:
@@ -243,7 +244,8 @@ class Quantity(numbers.Real):
         if isinstance(other, Quantity):
             return downgrade_to_scalar(
                 type(self)(
-                    self.magnitude // other.magnitude, self.signature / other.signature
+                    self.magnitude // other.magnitude,
+                    self.signature / other.signature,
                 )
             )
         else:
@@ -254,7 +256,8 @@ class Quantity(numbers.Real):
             other = type(self)(other, Signature())
             return downgrade_to_scalar(
                 type(self)(
-                    other.magnitude / self.magnitude, other.signature / self.signature
+                    other.magnitude / self.magnitude,
+                    other.signature / self.signature,
                 )
             )
         else:
@@ -267,7 +270,8 @@ class Quantity(numbers.Real):
             other = type(self)(other, Signature())
             return downgrade_to_scalar(
                 type(self)(
-                    other.magnitude // self.magnitude, other.signature / self.signature
+                    other.magnitude // self.magnitude,
+                    other.signature / self.signature,
                 )
             )
         else:
@@ -282,19 +286,19 @@ class Quantity(numbers.Real):
         elif isinstance(other, Quantity) and self.signature == other.signature:
             return self.magnitude == other.magnitude
         else:
-            raise TypeError("incomparable quantities: %r and %r" % (self, other))
+            return NotImplemented
 
     def __lt__(self, other):
         if isinstance(other, Quantity) and self.signature == other.signature:
             return self.magnitude < other.magnitude
         else:
-            raise TypeError("incomparable quantities: %r and %r" % (self, other))
+            return NotImplemented
 
     def __le__(self, other):
         if isinstance(other, Quantity) and self.signature == other.signature:
             return self.magnitude <= other.magnitude
         else:
-            raise TypeError("incomparable quantities: %r and %r" % (self, other))
+            return NotImplemented
 
     # The following make Quantity more compatible with numbers.Real.  In all
     # cases, taking a Quantity for a float takes the magnitude expressed in
@@ -446,7 +450,7 @@ class Dimension(type):
         *,
         unit_alias: str = None,
         unit_aliases: Sequence[str] = None,
-        Quantity: type = None
+        Quantity: type = None,
     ) -> Callable[[Any], "Dimension"]:
         ...
 
@@ -515,8 +519,8 @@ class Dimension(type):
         .. versionchanged:: 2.1.0 Added keyword parameter Quantity.
 
         """
-        from xotl.tools.objects import copy_class
         from xotl.tools.decorator.meta import decorator
+        from xotl.tools.objects import copy_class
 
         @decorator
         def _new(source, unit_alias=None, unit_aliases=None, Quantity=None):
@@ -615,10 +619,7 @@ class Dimension(type):
         if isinstance(other, Dimension):
             return self._signature_ == other._signature_
         else:
-            raise TypeError(
-                "incomparable types '%s' and '%s'"
-                % (type(self).__name__, type(other).__name__)
-            )
+            return NotImplemented
 
 
 class Signature:
@@ -711,10 +712,10 @@ class Signature:
         return res
 
     def __eq__(self, other):
-        if isinstance(other, type(self)):
+        if isinstance(other, Signature):
             return self._topset == other._topset and self._bottomset == other._bottomset
         else:
-            return False
+            return NotImplemented
 
     def __hash__(self):
         return hash(self._topset) + hash(self._bottomset)
@@ -857,9 +858,7 @@ class OperandTypeError(TypeError):
             t2 = val2.signature
         else:
             t2 = type(val2).__name__
-        super().__init__(
-            "unsupported operand type(s) for %s: '%s' and '%s'" % (operand, t1, t2)
-        )
+        super().__init__("unsupported operand type(s) for %s: '%s' and '%s'" % (operand, t1, t2))
 
 
 def downgrade_to_scalar(quantity):
